Crate clml_proc_macro

Crate clml_proc_macro 

This internal library provides the procedural macros needed by the crate clml.

Macros

cformat
The same as format!(), but parses color tags.
cstr
Colorizes a string literal, without formatting the format!-like placeholders.
cwrite
The same as write!(), but parses color tags.
cwriteln
The same as writeln!(), but parses color tags.
untagged
Removes all the color tags from the given string literal.